@@ -20,8 +20,7 @@ class pyLight:
     @property
     def state(self):
         """State of the light."""
-        if self.__device.value is None:
-            self.__device.observe()
+        self.__device.observe()
 
         if self.has_brightness:
             return (True if self.__device.value > MIN_RANGE else False)
@@ -57,6 +56,10 @@ class pyLight:
 
     def turn_off(self):
         """Turn off the light."""
+        if self.has_brightness is True:
+            self.__device.set_value(MIN_RANGE)
+            return
+
         self.__device.set_value(ATTR_SWITCH_OFF)
 
     def turn_on(self):
